Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(969)

Unified Diff: content/common/device_sensors/device_light_messages.h

Issue 286793002: [DeviceLight] Add renderer+common parts (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: jochen's comments Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/device_sensors/device_light_hardware_buffer.h ('k') | content/content_common.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/device_sensors/device_light_messages.h
diff --git a/content/common/device_sensors/device_motion_messages.h b/content/common/device_sensors/device_light_messages.h
similarity index 51%
copy from content/common/device_sensors/device_motion_messages.h
copy to content/common/device_sensors/device_light_messages.h
index 4b17d1024dcdc49519ccc2b509501253789730b2..4fad255468b20817de80fd20fdb1c54542a619d8 100644
--- a/content/common/device_sensors/device_motion_messages.h
+++ b/content/common/device_sensors/device_light_messages.h
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// IPC messages for device motion.
// Multiply-included message file, hence no include guard.
#include "base/memory/shared_memory.h"
@@ -10,19 +10,17 @@
#include "ipc/ipc_param_traits.h"
#include "ipc/ipc_platform_file.h"
-#define IPC_MESSAGE_START DeviceMotionMsgStart
+#define IPC_MESSAGE_START DeviceLightMsgStart
-// Asks the browser process to activate Device Motion sensors if necessary.
-IPC_MESSAGE_CONTROL0(DeviceMotionHostMsg_StartPolling)
+// Asks the browser process to activate Device Light sensors if necessary.
+IPC_MESSAGE_CONTROL0(DeviceLightHostMsg_StartPolling)
-// The browser process asynchronously returns the shared memory handle that will
-// hold the data from the hardware sensors.
-// See device_motion_hardware_buffer.h for a description of how
-// synchronization is handled.
-IPC_MESSAGE_CONTROL1(DeviceMotionMsg_DidStartPolling,
+// The browser process asynchronously returns the shared memory handle that
+// will hold the data from the hardware sensors.
+IPC_MESSAGE_CONTROL1(DeviceLightMsg_DidStartPolling,
base::SharedMemoryHandle /* handle */)
// Notifies the browser process that the renderer process is not using the
// Device Motion data anymore. The number of Starts should match the number
// of Stops.
-IPC_MESSAGE_CONTROL0(DeviceMotionHostMsg_StopPolling)
+IPC_MESSAGE_CONTROL0(DeviceLightHostMsg_StopPolling)
« no previous file with comments | « content/common/device_sensors/device_light_hardware_buffer.h ('k') | content/content_common.gypi » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// IPC messages for device motion.
+// IPC messages for device light.
// Multiply-included message file, hence no include guard.
#include "base/memory/shared_memory.h"
@@ -10,19 +10,17 @@
base::SharedMemoryHandle /* handle */)
// Notifies the browser process that the renderer process is not using the
-// Device Motion data anymore. The number of Starts should match the number
+// Device Light data anymore. The number of Starts should match the number
// of Stops.
This is Rietveld 408576698